@@ -10,12 +10,20 @@ Usage::
     client: EMRContainersClient = boto3.client("emr-containers")
     ```
 """
-import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_emr_containers.literals import (
+    ContainerProviderType,
+    EndpointState,
+    JobRunState,
+    ListJobRunsPaginatorName,
+    ListManagedEndpointsPaginatorName,
+    ListVirtualClustersPaginatorName,
+    VirtualClusterState,
+)
 from mypy_boto3_emr_containers.paginator import (
     ListJobRunsPaginator,
     ListManagedEndpointsPaginator,
@@ -40,12 +48,6 @@ from mypy_boto3_emr_containers.type_defs import (
     StartJobRunResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("EMRContainersClient",)
 
 
@@ -66,7 +68,7 @@ class Exceptions:
 
 class EMRContainersClient:
     """
-    [EMRContainers.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client)
+    [EMRContainers.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client)
     """
 
     meta: ClientMeta
@@ -74,12 +76,12 @@ class EMRContainersClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
         """
 
     def cancel_job_run(self, id: str, virtualClusterId: str) -> CancelJobRunResponseTypeDef:
         """
-        [Client.cancel_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
+        [Client.cancel_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
         """
 
     def create_managed_endpoint(
@@ -95,7 +97,7 @@ class EMRContainersClient:
         tags: Dict[str, str] = None,
     ) -> CreateManagedEndpointResponseTypeDef:
         """
-        [Client.create_managed_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
+        [Client.create_managed_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
         """
 
     def create_virtual_cluster(
@@ -106,36 +108,36 @@ class EMRContainersClient:
         tags: Dict[str, str] = None,
     ) -> CreateVirtualClusterResponseTypeDef:
         """
-        [Client.create_virtual_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
+        [Client.create_virtual_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
         """
 
     def delete_managed_endpoint(
         self, id: str, virtualClusterId: str
     ) -> DeleteManagedEndpointResponseTypeDef:
         """
-        [Client.delete_managed_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
+        [Client.delete_managed_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
         """
 
     def delete_virtual_cluster(self, id: str) -> DeleteVirtualClusterResponseTypeDef:
         """
-        [Client.delete_virtual_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
+        [Client.delete_virtual_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
         """
 
     def describe_job_run(self, id: str, virtualClusterId: str) -> DescribeJobRunResponseTypeDef:
         """
-        [Client.describe_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
+        [Client.describe_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
         """
 
     def describe_managed_endpoint(
         self, id: str, virtualClusterId: str
     ) -> DescribeManagedEndpointResponseTypeDef:
         """
-        [Client.describe_managed_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
+        [Client.describe_managed_endpoint documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
         """
 
     def describe_virtual_cluster(self, id: str) -> DescribeVirtualClusterResponseTypeDef:
         """
-        [Client.describe_virtual_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
+        [Client.describe_virtual_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
         """
 
     def generate_presigned_url(
@@ -146,7 +148,7 @@ class EMRContainersClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
         """
 
     def list_job_runs(
@@ -155,22 +157,12 @@ class EMRContainersClient:
         createdBefore: datetime = None,
         createdAfter: datetime = None,
         name: str = None,
-        states: List[
-            Literal[
-                "PENDING",
-                "SUBMITTED",
-                "RUNNING",
-                "FAILED",
-                "CANCELLED",
-                "CANCEL_PENDING",
-                "COMPLETED",
-            ]
-        ] = None,
+        states: List[JobRunState] = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListJobRunsResponseTypeDef:
         """
-        [Client.list_job_runs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
+        [Client.list_job_runs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
         """
 
     def list_managed_endpoints(
@@ -179,33 +171,31 @@ class EMRContainersClient:
         createdBefore: datetime = None,
         createdAfter: datetime = None,
         types: List[str] = None,
-        states: List[
-            Literal["CREATING", "ACTIVE", "TERMINATING", "TERMINATED", "TERMINATED_WITH_ERRORS"]
-        ] = None,
+        states: List[EndpointState] = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListManagedEndpointsResponseTypeDef:
         """
-        [Client.list_managed_endpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
+        [Client.list_managed_endpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
         """
 
     def list_virtual_clusters(
         self,
         containerProviderId: str = None,
-        containerProviderType: Literal["EKS"] = None,
+        containerProviderType: ContainerProviderType = None,
         createdAfter: datetime = None,
         createdBefore: datetime = None,
-        states: List[Literal["RUNNING", "TERMINATING", "TERMINATED", "ARRESTED"]] = None,
+        states: List[VirtualClusterState] = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListVirtualClustersResponseTypeDef:
         """
-        [Client.list_virtual_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
+        [Client.list_virtual_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
         """
 
     def start_job_run(
@@ -220,37 +210,37 @@ class EMRContainersClient:
         tags: Dict[str, str] = None,
     ) -> StartJobRunResponseTypeDef:
         """
-        [Client.start_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
+        [Client.start_job_run documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
+    def get_paginator(self, operation_name: ListJobRunsPaginatorName) -> ListJobRunsPaginator:
         """
-        [Paginator.ListJobRuns documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
+        [Paginator.ListJobRuns documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_managed_endpoints"]
+        self, operation_name: ListManagedEndpointsPaginatorName
     ) -> ListManagedEndpointsPaginator:
         """
-        [Paginator.ListManagedEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
+        [Paginator.ListManagedEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_virtual_clusters"]
+        self, operation_name: ListVirtualClustersPaginatorName
     ) -> ListVirtualClustersPaginator:
         """
-        [Paginator.ListVirtualClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
+        [Paginator.ListVirtualClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
         """
