@@ -20,12 +20,17 @@ Usage::
     list_virtual_clusters_paginator: ListVirtualClustersPaginator = client.get_paginator("list_virtual_clusters")
     ```
 """
-import sys
 from datetime import datetime
 from typing import Iterator, List
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_emr_containers.literals import (
+    ContainerProviderType,
+    EndpointState,
+    JobRunState,
+    VirtualClusterState,
+)
 from mypy_boto3_emr_containers.type_defs import (
     ListJobRunsResponseTypeDef,
     ListManagedEndpointsResponseTypeDef,
@@ -33,18 +38,12 @@ from mypy_boto3_emr_containers.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("ListJobRunsPaginator", "ListManagedEndpointsPaginator", "ListVirtualClustersPaginator")
 
 
 class ListJobRunsPaginator(Boto3Paginator):
     """
-    [Paginator.ListJobRuns documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
+    [Paginator.ListJobRuns documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)
     """
 
     def paginate(
@@ -53,27 +52,17 @@ class ListJobRunsPaginator(Boto3Paginator):
         createdBefore: datetime = None,
         createdAfter: datetime = None,
         name: str = None,
-        states: List[
-            Literal[
-                "PENDING",
-                "SUBMITTED",
-                "RUNNING",
-                "FAILED",
-                "CANCELLED",
-                "CANCEL_PENDING",
-                "COMPLETED",
-            ]
-        ] = None,
+        states: List[JobRunState] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListJobRunsResponseTypeDef]:
         """
-        [ListJobRuns.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns.paginate)
+        [ListJobRuns.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns.paginate)
         """
 
 
 class ListManagedEndpointsPaginator(Boto3Paginator):
     """
-    [Paginator.ListManagedEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
+    [Paginator.ListManagedEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)
     """
 
     def paginate(
@@ -82,30 +71,28 @@ class ListManagedEndpointsPaginator(Boto3Paginator):
         createdBefore: datetime = None,
         createdAfter: datetime = None,
         types: List[str] = None,
-        states: List[
-            Literal["CREATING", "ACTIVE", "TERMINATING", "TERMINATED", "TERMINATED_WITH_ERRORS"]
-        ] = None,
+        states: List[EndpointState] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListManagedEndpointsResponseTypeDef]:
         """
-        [ListManagedEndpoints.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints.paginate)
+        [ListManagedEndpoints.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints.paginate)
         """
 
 
 class ListVirtualClustersPaginator(Boto3Paginator):
     """
-    [Paginator.ListVirtualClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
+    [Paginator.ListVirtualClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)
     """
 
     def paginate(
         self,
         containerProviderId: str = None,
-        containerProviderType: Literal["EKS"] = None,
+        containerProviderType: ContainerProviderType = None,
         createdAfter: datetime = None,
         createdBefore: datetime = None,
-        states: List[Literal["RUNNING", "TERMINATING", "TERMINATED", "ARRESTED"]] = None,
+        states: List[VirtualClusterState] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListVirtualClustersResponseTypeDef]:
         """
-        [ListVirtualClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters.paginate)
+        [ListVirtualClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters.paginate)
         """
