@@ -13,10 +13,15 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_emr_containers.literals import (
+    ContainerProviderType,
+    EndpointState,
+    FailureReason,
+    JobRunState,
+    PersistentAppUI,
+    VirtualClusterState,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -80,7 +85,7 @@ ConfigurationOverridesTypeDef = TypedDict(
 ContainerInfoTypeDef = TypedDict("ContainerInfoTypeDef", {"eksInfo": "EksInfoTypeDef"}, total=False)
 
 _RequiredContainerProviderTypeDef = TypedDict(
-    "_RequiredContainerProviderTypeDef", {"type": Literal["EKS"], "id": str}
+    "_RequiredContainerProviderTypeDef", {"type": ContainerProviderType, "id": str}
 )
 _OptionalContainerProviderTypeDef = TypedDict(
     "_OptionalContainerProviderTypeDef", {"info": "ContainerInfoTypeDef"}, total=False
@@ -103,9 +108,7 @@ EndpointTypeDef = TypedDict(
         "arn": str,
         "virtualClusterId": str,
         "type": str,
-        "state": Literal[
-            "CREATING", "ACTIVE", "TERMINATING", "TERMINATED", "TERMINATED_WITH_ERRORS"
-        ],
+        "state": EndpointState,
         "releaseLabel": str,
         "executionRoleArn": str,
         "certificateArn": str,
@@ -130,9 +133,7 @@ JobRunTypeDef = TypedDict(
         "name": str,
         "virtualClusterId": str,
         "arn": str,
-        "state": Literal[
-            "PENDING", "SUBMITTED", "RUNNING", "FAILED", "CANCELLED", "CANCEL_PENDING", "COMPLETED"
-        ],
+        "state": JobRunState,
         "clientToken": str,
         "executionRoleArn": str,
         "releaseLabel": str,
@@ -142,9 +143,7 @@ JobRunTypeDef = TypedDict(
         "createdBy": str,
         "finishedAt": datetime,
         "stateDetails": str,
-        "failureReason": Literal[
-            "INTERNAL_ERROR", "USER_ERROR", "VALIDATION_ERROR", "CLUSTER_UNAVAILABLE"
-        ],
+        "failureReason": FailureReason,
         "tags": Dict[str, str],
     },
     total=False,
@@ -153,7 +152,7 @@ JobRunTypeDef = TypedDict(
 MonitoringConfigurationTypeDef = TypedDict(
     "MonitoringConfigurationTypeDef",
     {
-        "persistentAppUI": Literal["ENABLED", "DISABLED"],
+        "persistentAppUI": PersistentAppUI,
         "cloudWatchMonitoringConfiguration": "CloudWatchMonitoringConfigurationTypeDef",
         "s3MonitoringConfiguration": "S3MonitoringConfigurationTypeDef",
     },
@@ -184,7 +183,7 @@ VirtualClusterTypeDef = TypedDict(
         "id": str,
         "name": str,
         "arn": str,
-        "state": Literal["RUNNING", "TERMINATING", "TERMINATED", "ARRESTED"],
+        "state": VirtualClusterState,
         "containerProvider": "ContainerProviderTypeDef",
         "createdAt": datetime,
         "tags": Dict[str, str],
